<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>Zojuist</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 nieuwe melding</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minuten geleden</translation>
    </message>
</context>
</TS>